import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { NotificationsClientResolvedConfig } from "../NotificationsClient";
/**
 * @internal
 */
export interface NotificationsHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface NotificationsHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<NotificationsClientResolvedConfig, HandlerExecutionContext, NotificationsHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultNotificationsHttpAuthSchemeParametersProvider: (config: NotificationsClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<NotificationsHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface NotificationsHttpAuthSchemeProvider extends HttpAuthSchemeProvider<NotificationsHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultNotificationsHttpAuthSchemeProvider: NotificationsHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: NotificationsHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: NotificationsHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
