import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListManagedNotificationChannelAssociationsRequest, ListManagedNotificationChannelAssociationsResponse } from "../models/models_0";
import { NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../NotificationsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListManagedNotificationChannelAssociationsCommand}.
 */
export interface ListManagedNotificationChannelAssociationsCommandInput extends ListManagedNotificationChannelAssociationsRequest {
}
/**
 * @public
 *
 * The output of {@link ListManagedNotificationChannelAssociationsCommand}.
 */
export interface ListManagedNotificationChannelAssociationsCommandOutput extends ListManagedNotificationChannelAssociationsResponse, __MetadataBearer {
}
declare const ListManagedNotificationChannelAssociationsCommand_base: {
    new (input: ListManagedNotificationChannelAssociationsCommandInput): import("@smithy/smithy-client").CommandImpl<ListManagedNotificationChannelAssociationsCommandInput, ListManagedNotificationChannelAssociationsCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ListManagedNotificationChannelAssociationsCommandInput): import("@smithy/smithy-client").CommandImpl<ListManagedNotificationChannelAssociationsCommandInput, ListManagedNotificationChannelAssociationsCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a list of Account contacts and Channels associated with a <code>ManagedNotificationConfiguration</code>, in paginated format.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { NotificationsClient, ListManagedNotificationChannelAssociationsCommand } from "@aws-sdk/client-notifications"; // ES Modules import
 * // const { NotificationsClient, ListManagedNotificationChannelAssociationsCommand } = require("@aws-sdk/client-notifications"); // CommonJS import
 * const client = new NotificationsClient(config);
 * const input = { // ListManagedNotificationChannelAssociationsRequest
 *   managedNotificationConfigurationArn: "STRING_VALUE", // required
 *   maxResults: Number("int"),
 *   nextToken: "STRING_VALUE",
 * };
 * const command = new ListManagedNotificationChannelAssociationsCommand(input);
 * const response = await client.send(command);
 * // { // ListManagedNotificationChannelAssociationsResponse
 * //   nextToken: "STRING_VALUE",
 * //   channelAssociations: [ // ManagedNotificationChannelAssociations // required
 * //     { // ManagedNotificationChannelAssociationSummary
 * //       channelIdentifier: "STRING_VALUE", // required
 * //       channelType: "STRING_VALUE", // required
 * //       overrideOption: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListManagedNotificationChannelAssociationsCommandInput - {@link ListManagedNotificationChannelAssociationsCommandInput}
 * @returns {@link ListManagedNotificationChannelAssociationsCommandOutput}
 * @see {@link ListManagedNotificationChannelAssociationsCommandInput} for command's `input` shape.
 * @see {@link ListManagedNotificationChannelAssociationsCommandOutput} for command's `response` shape.
 * @see {@link NotificationsClientResolvedConfig | config} for NotificationsClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>User does not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Unexpected error during processing of request.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Request references a resource which does not exist. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Request was denied due to request throttling. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>This exception is thrown when the notification event fails validation.</p>
 *
 * @throws {@link NotificationsServiceException}
 * <p>Base exception class for all service exceptions from Notifications service.</p>
 *
 * @public
 */
export declare class ListManagedNotificationChannelAssociationsCommand extends ListManagedNotificationChannelAssociationsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListManagedNotificationChannelAssociationsRequest;
            output: ListManagedNotificationChannelAssociationsResponse;
        };
        sdk: {
            input: ListManagedNotificationChannelAssociationsCommandInput;
            output: ListManagedNotificationChannelAssociationsCommandOutput;
        };
    };
}
